@@ -706,7 +706,8 @@ class Island:
         Returns:
             gene: A new Gene object.
         """
-        return Gene(name, value, randomise_function, gene_max, gene_min, mu, sig, choices, gene_properties)
+        return Gene(name=name, value=value, randomise_function=randomise_function, gene_max=gene_max, gene_min=gene_min,
+                    mu=mu, sig=sig, choices=choices, gene_properties=gene_properties)
 
     def create_chromosome(self,
                           genes: list = None,
@@ -723,7 +724,7 @@ class Island:
         Returns:
             chromosome: A new Chromosome.
         """
-        return Chromosome(genes, gene_verify_func, chromosome_properties)
+        return Chromosome(genes=genes, gene_verify_func=gene_verify_func, chromosome_properties=chromosome_properties)
 
     def create_individual(self,
                           fitness_function : Callable,
@@ -746,7 +747,8 @@ class Island:
         Returns:
             individual: A new Individual.
         """
-        ind = Individual(fitness_function, name, chromosome, species_type, individual_properties)
+        ind = Individual(fitness_function=fitness_function, name=name, chromosome=chromosome, species_type=species_type,
+                         individual_properties=individual_properties)
         if add_to_population:
             self.population.append(ind)
         return ind
