@@ -1,3 +1,5 @@
+import copy
+
 def initialise_population_random(adam, n : int = 10, island=None):
     """
     Classic random initialisation function to create a pool of `n` individuals from a starting Individual `adam`.
@@ -13,8 +15,13 @@ def initialise_population_random(adam, n : int = 10, island=None):
     population = list()
 
     for i in range(n - 1):
-        chromosome = island.create_chromosome([x.randomise_new() for x in adam.chromosome])
-        eve = island.create_individual(adam.fitness_function, chromosome=chromosome)
+        chromosome = island.create_chromosome(genes=[x.randomise_new() for x in adam.chromosome],
+                                              gene_verify_func=adam.chromosome.gene_verify_func,
+                                              chromosome_properties=copy.deepcopy(adam.chromosome.get_properties()))
+        eve = island.create_individual(adam.fitness_function,
+                                       chromosome=chromosome,
+                                       species_type=adam.species_type,
+                                       individual_properties=copy.deepcopy(adam.get_properties()))
         population.append(eve)
 
     population.append(adam)
@@ -34,7 +41,6 @@ def initialise_population_mutation_function(adam, n : int = 10, mutation_params
     Returns:
         list: Population members.
     """
-    import copy
 
     population = list()
 
@@ -44,7 +50,10 @@ def initialise_population_mutation_function(adam, n : int = 10, mutation_params
         _mutation_params = {}
 
     for i in range(n - 1):
-        eve = island.create_individual(adam.fitness_function, chromosome=copy.deepcopy(adam.chromosome))
+        eve = island.create_individual(adam.fitness_function,
+                                       chromosome=copy.deepcopy(adam.chromosome),
+                                       species_type=adam.species_type,
+                                       individual_properties=copy.deepcopy(adam.get_properties()))
         eve = island.mutation(island=island, individual=eve, **_mutation_params)
         population.append(eve)
 
